/**
 * Copyright (C) 2012 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.dashboard.command;

import org.jboss.dashboard.provider.DataFilter;

import java.util.ArrayList;
import java.util.List;

/**
 * Base class for the implementation of custom commands.
 */
public abstract class AbstractCommand implements Command {

    protected String name;
    protected List<String> arguments;
    protected DataFilter dataFilter;

    public AbstractCommand() {
        arguments = new ArrayList<String>();
    }

    public AbstractCommand(String name) {
        this();
        this.name = name;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public List<String> getArguments() {
        return arguments;
    }

    public void setArguments(List<String> arguments) {
        this.arguments = arguments;
    }

    public DataFilter getDataFilter() {
        return dataFilter;
    }

    public void setDataFilter(DataFilter dataFilter) {
        this.dataFilter = dataFilter;
    }

    public String getArgument(int index) {
        if (arguments.size() <= index) return null;
        return getArguments().get(index);
    }

    public boolean containsProperty(String propertyId) throws Exception {
        return false;
    }

    public abstract String execute() throws Exception;
}
